clc; clear;

%%% Constants %%%
E = 8e9;
C = 0;
A = (75e-6)*(5.8e-2);
L = 0.55;
md = 0.5;
Kd = 1080;
Bd = 15; %1/2*sqrt(md)*sqrt(Kd)*10;
g = 9.82;
T_ref = 25;
Fx = 22;
d_ref = (2*T_ref-Fx)/Kd;
LN = L - 2*d_ref;
V1 = 0.1;
Bm = 5e-4;
J = 0.309e-2;
R = 0.013; %13
N = 10.75;
%e = E*A/L;
%c = C*A/L;
%v = V1/L;
core_r = 0.013; % m
paper_thickness = 7.5e-5; % m
Ts = 1/1000;

%%% Intial Conditions %%%
%ic = [15.3719 22.4448 0 0.0400]; % omega tension v_d d
ic = [0 Fx/2 0 0];


%%% State Space Model %%%
Aa = [-Bm/J        -R/(N*J)  0          0;
       E*A/LN*R/N  -V1/LN   -2*E*A/LN   0;
       0            2/md    -Bd/md     -Kd/md;
       0            0        1          0];

Bb = [1/J  0       0;
      0   -E*A/LN  0
      0    0       1/md
      0    0       0];

% Cc = [1 0 0 0;
%     0 0 0 1];
Cc = [0 0 0 1];

Dd = 0;

sys = ss(Aa,Bb,Cc,Dd);


%%% Integrator %%%
Ccc = [0 0 0 1 0];
Aaa = [Aa zeros(size(Aa,1),1); Ccc];
Bbb = [Bb(:,1); 0];


Rmat = 1/0.1^2;
Qmat = diag([1/(1000/60*2*pi)^2 1/100^2 1/1^2 1/0.1^2 1/(1e-3)^2]); % omega tension dancer_vel dancer_position
K = lqr(Aaa, Bbb, Qmat, Rmat);


%%% Observer %%%
Cobs = [1 0 0 0
    0 0 0 1];
Qobs=diag([10 1 0.1 1e-3]);
Robs=diag([0.1e-3 0.1e-3]);
Gobs=eye(4);
Lobs=lqe(Aa,Gobs,Cobs,Qobs,Robs);

%%%%%%%%%%%%%%%%%%%%%%%
% Some experiments    %
%%%%%%%%%%%%%%%%%%%%%%%
C = E/1e3;

c = C*A/LN;
% J = 10*J;

Aa1 = [-Bm/J-R/N*c*R/N/J        -R/(N*J)  2*c*R/N/J          0;
        E*A/LN*R/N-R/N*c*V1/LN  -V1/LN   -2*E*A/LN+2*c*V1/LN   0;
        R/N*c*2/md            2/md    -Bd/md     -Kd/md;
        0            0        1          0];


Bb1 = [1/J  c*R/N/J       0
      0   -E*A/LN+c*V1/LN  0
      0    0       1/md
      0    0       0];